@@ -181,8 +181,7 @@
 //! from anywhere by using hidden submodules. However, unverifiable users (C libraries) may still
 //! be able to modify the tables. This library assumes they are not malicious and does not
 //! perform any runtime verification. API version mismatch checking with
-//! [abi\_stable](https://crates.io/crates/abi_stable) is an opt-in feature (requires rustc 1.46+,
-//! and abi_stable git, or 0.10.4 version).
+//! [abi\_stable](https://crates.io/crates/abi_stable) is an opt-in feature (requires rustc 1.46+).
 //!
 //! Other than 2 bits in [associated type wrapping](#associated-type-wrapping), this crate should
 //! be safe.
@@ -942,6 +941,7 @@ pub mod repr_cstring;
 pub mod result;
 pub mod slice;
 pub mod trait_group;
+pub mod vec;
 
 pub use ::cglue_macro::{
     as_mut, as_ref, cast, cglue_forward, cglue_forward_ext, cglue_impl_group, cglue_trait,
@@ -966,8 +966,8 @@ pub mod prelude {
     pub mod v1 {
         pub use crate::{
             arc::CArc,
-            boxed::CBox,
-            callback::{Callback, FeedCallback, FromExtend, OpaqueCallback},
+            boxed::{CBox, CSliceBox},
+            callback::{Callback, Callbackable, FeedCallback, FromExtend, OpaqueCallback},
             forward::{Forward, ForwardMut, Fwd},
             iter::CIterator,
             option::COption,
@@ -975,6 +975,7 @@ pub mod prelude {
             result::{CResult, IntError, IntResult},
             slice::{CSliceMut, CSliceRef},
             trait_group::Opaquable,
+            vec::CVec,
             *,
         };
 
